@@ -1,7 +1,8 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2011 Piotr Eljasiak
+    Copyright (C) 2007-2012 Piotr Eljasiak
+    Copyright (C) 2013 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -184,7 +185,7 @@ GnomeCmdFileList::Private::~Private()
 inline gchar *strip_extension (const gchar *fname)
 {
     gchar *s = g_strdup (fname);
-    gchar *p = g_strrstr (s, ".");
+    gchar *p = strrchr(s,'.');
     if (p && p != s)
         *p = '\0';
     return s;
@@ -867,22 +868,23 @@ static gint sort_by_dir (GnomeCmdFile *f1, GnomeCmdFile *f2, GnomeCmdFileList *f
     if (f1->info->type < f2->info->type)
         return 1;
 
-    // gchar *t1 = gnome_cmd_file_get_path (f1);
-    // gchar *t2 = gnome_cmd_file_get_path (f2);
-    // gchar *d1 = g_path_get_dirname (t1);
-    // gchar *d2 = g_path_get_dirname (t2);
-
     gboolean raising = fl->priv->sort_raising[fl->priv->current_col];
-    // gint ret = my_strcmp (d1, d2, raising);
+    gchar *t1 = gnome_cmd_file_get_path (f1);
+    gchar *t2 = gnome_cmd_file_get_path (f2);
+    gchar *d1 = g_path_get_dirname (t1);
+    gchar *d2 = g_path_get_dirname (t2);
 
-    // g_free (t1);
-    // g_free (t2);
-    // g_free (d1);
-    // g_free (d2);
+    gint ret = my_strcmp (d1, d2, raising);
 
-    // return ret;
+    g_free (t1);
+    g_free (t2);
+    g_free (d1);
+    g_free (d2);
 
-    return my_strcmp (gnome_cmd_file_get_collation_fname (f1), gnome_cmd_file_get_collation_fname (f2), raising);
+    if (!ret)
+        ret = my_strcmp (gnome_cmd_file_get_collation_fname (f1), gnome_cmd_file_get_collation_fname (f2), raising);
+
+    return ret;
 }
 
 
