@@ -1,7 +1,8 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2011 Piotr Eljasiak
+    Copyright (C) 2007-2012 Piotr Eljasiak
+    Copyright (C) 2013 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -1130,7 +1131,7 @@ void command_root_mode (GtkMenuItem *menuitem, gpointer not_used)
     argv[i++] = su;
     if (need_c)
         argv[i++] = "-c";
-    argv[i++] = g_get_prgname ();
+    argv[i++] = g_strdup (g_get_prgname ());
     argv[i++] = NULL;
 
     GError *error = NULL;
@@ -1594,7 +1595,7 @@ void help_about (GtkMenuItem *menuitem, gpointer not_used)
     };
 
     static const gchar copyright[] = "Copyright \xc2\xa9 2001-2006 Marcus Bjurman\n"
-                                     "Copyright \xc2\xa9 2007-2011 Piotr Eljasiak";
+                                     "Copyright \xc2\xa9 2007-2012 Piotr Eljasiak";
 
     static const gchar comments[] = N_("A fast and powerful file manager for the GNOME desktop");
 
