@@ -5,7 +5,8 @@
     Part of
         GNOME Commander - A GNOME based file manager
         Copyright (C) 2001-2006 Marcus Bjurman
-        Copyright (C) 2007-2011 Piotr Eljasiak
+        Copyright (C) 2007-2012 Piotr Eljasiak
+    Copyright (C) 2013 Uwe Scholz
 
     Partly based on "gtkhex.c" module from "GHex2" Project.
     Author: Jaka Mocnik <jaka@gnu.org>
@@ -1484,7 +1485,7 @@ void text_render_set_encoding(TextRender *w, const char *encoding)
         return;
 
     // Ugly hack: UTF-8 is not acceptable encoding in Binary/Hexdump modes
-    if (g_strcasecmp(encoding, "UTF8")==0 && (
+    if (g_ascii_strcasecmp (encoding, "UTF8")==0 && (
         w->priv->dispmode==TR_DISP_MODE_BINARY || w->priv->dispmode==TR_DISP_MODE_HEXDUMP))
         {
             g_warning("Can't set UTF8 encoding when in Binary or HexDump display mode");
