@@ -1,7 +1,8 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2011 Piotr Eljasiak
+    Copyright (C) 2007-2012 Piotr Eljasiak
+    Copyright (C) 2013 Uwe Scholz
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,8 +41,16 @@ using namespace std;
 #ifdef HAVE_PDF
 static regex_t rxDate;
 static gboolean rxDate_OK;
-
+#ifdef POPPLER_HAS_SET_ERROR_CALLBACK
+#ifdef POPPLER_HAS_GOFFSET
+typedef Goffset gcmd_poppler_offset_t;
+#else
+typedef int gcmd_poppler_offset_t;
+#endif
+static void noErrorReporting(void *, ErrorCategory, gcmd_poppler_offset_t pos, char *msg)
+#else
 static void noErrorReporting(int pos, char *msg, va_list args)
+#endif
 {
 }
 #endif
@@ -52,8 +61,12 @@ void gcmd_tags_poppler_init()
 #ifdef HAVE_PDF
     rxDate_OK = regcomp (&rxDate, "^(D:)?([12][019][0-9][0-9]([01][0-9]([0-3][0-9]([012][0-9]([0-5][0-9]([0-5][0-9])?)?)?)?)?)", REG_EXTENDED)==0;
 
+#ifdef POPPLER_HAS_SET_ERROR_CALLBACK
+    setErrorCallback(noErrorReporting, NULL);
+#else
     setErrorFunction(noErrorReporting);
 #endif
+#endif
 }
 
 
